@@ -1,5 +1,6 @@
 from __future__ import absolute_import
 import os
+import sys
 import errno
 import signal
 import socket
@@ -188,7 +189,7 @@ class WorkerProcess(object):
         logger.debug("Running worker command")
         run_worker(self.kuyruk, args)
 
-        os._exit(0)
+        sys.exit(0)
 
     def close_fds(self):
         logger.debug("Closing open file descriptors...")
@@ -196,25 +197,8 @@ class WorkerProcess(object):
         if maxfd == resource.RLIM_INFINITY:
             maxfd = 1024
 
-        # Iterate through and close all file descriptors.
         # Do not close stdin, stdout and stderr (0, 1, 2)
-        for fd in range(3, maxfd):
-            try:
-                os.close(fd)
-            except OSError:  # fd wasn't open
-                pass
-
-    def is_alive(self):
-        """Send signal 0 to process to check if it is alive."""
-        logger.debug("Cheking if the worker is alive? pid=%s", self.pid)
-        try:
-            os.kill(self.pid, 0)
-        except OSError:
-            logger.debug("No")
-            return False
-        else:
-            logger.debug("Yes")
-            return True
+        os.closerange(3, maxfd)
 
     def kill_pg(self):
         """Kill the process with their children. Does not raise exception
