@@ -12,6 +12,7 @@ kuyruk = Kuyruk()
 @kuyruk.task
 def print_task(message):
     print message
+    must_be_called()
 
 
 @kuyruk.task(queue='another_queue')
@@ -38,8 +39,7 @@ def loop_forever():
 
 @kuyruk.task(eager=True)
 def eager_task():
-    eager_called.append(1)
-eager_called = []
+    must_be_called()
 
 
 @kuyruk.task
@@ -64,8 +64,7 @@ def task_with_functions(message):
 
 @kuyruk2.on_presend
 def function0(sender, task, args, kwargs):
-    presend_called.append(1)
-presend_called = []
+    must_be_called()
 
 
 @kuyruk2.on_prerun
@@ -116,12 +115,44 @@ class Cat(object):
     @kuyruk.task
     def meow(self, message):
         print "Felix says:", message
+        must_be_called()
+
+    @kuyruk.task(eager=True)
+    def meow_eager(self, message):
+        print "Felix says:", message
+        must_be_called()
 
     @kuyruk.task
     def raise_exception(self):
         raise Exception
 
 
+@kuyruk.task(arg_class=Cat)
+def jump(cat):
+    print "%s jumps high!" % cat.name
+    must_be_called(cat.name)
+
+
+@kuyruk.task(arg_class=Cat, eager=True)
+def jump_eager(cat):
+    print "%s jumps high!" % cat.name
+    must_be_called(cat.name)
+
+
+@kuyruk.task(arg_class=Cat)
+def jump_fail(cat):
+    1/0
+
+
+def must_be_called(arg=None):
+    """
+    This function is patched in tests to see the caller is doing it's job.
+
+    """
+    print 'Yes, it is called.'
+    print 'Called with %s' % arg
+
+
 class DatabaseTask(Task):
 
     def setup(self):
